anagram
=======

I'm a small script that help you get anagram use wordsmith.org.

Install
-------

::

    sudo pip install anagram

Usage
-----

use a single word
~~~~~~~~~~~~~~~~~

::

    $ anagram cat
    1. act
    2. cat

use a sentence
~~~~~~~~~~~~~~

::

    $  anagram a dog
    1. goad
    2. a god
    3. a dog
    4. ad go

LICENSE
-------

MIT
